Garfield.nn.GATDecoder
======================

.. currentmodule:: Garfield.nn

.. autoclass:: GATDecoder

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GATDecoder.__init__
      ~GATDecoder.add_module
      ~GATDecoder.apply
      ~GATDecoder.bfloat16
      ~GATDecoder.buffers
      ~GATDecoder.children
      ~GATDecoder.compile
      ~GATDecoder.cpu
      ~GATDecoder.cuda
      ~GATDecoder.double
      ~GATDecoder.eval
      ~GATDecoder.extra_repr
      ~GATDecoder.float
      ~GATDecoder.forward
      ~GATDecoder.get_buffer
      ~GATDecoder.get_extra_state
      ~GATDecoder.get_parameter
      ~GATDecoder.get_submodule
      ~GATDecoder.half
      ~GATDecoder.ipu
      ~GATDecoder.load_state_dict
      ~GATDecoder.modules
      ~GATDecoder.named_buffers
      ~GATDecoder.named_children
      ~GATDecoder.named_modules
      ~GATDecoder.named_parameters
      ~GATDecoder.parameters
      ~GATDecoder.register_backward_hook
      ~GATDecoder.register_buffer
      ~GATDecoder.register_forward_hook
      ~GATDecoder.register_forward_pre_hook
      ~GATDecoder.register_full_backward_hook
      ~GATDecoder.register_full_backward_pre_hook
      ~GATDecoder.register_load_state_dict_post_hook
      ~GATDecoder.register_module
      ~GATDecoder.register_parameter
      ~GATDecoder.register_state_dict_pre_hook
      ~GATDecoder.requires_grad_
      ~GATDecoder.set_extra_state
      ~GATDecoder.share_memory
      ~GATDecoder.state_dict
      ~GATDecoder.to
      ~GATDecoder.to_empty
      ~GATDecoder.train
      ~GATDecoder.type
      ~GATDecoder.xpu
      ~GATDecoder.zero_grad
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GATDecoder.T_destination
      ~GATDecoder.call_super_init
      ~GATDecoder.dump_patches
      ~GATDecoder.training
   
   